==> nstation_rh61_cfbuilder_2.3.01.tar: IBM/CFBuilder_2.3/Source/wiz_selectpack.tcl <==
#.------------------------------------------------------------,
#| Compact Flash Builder - IBM Embedded Linux Network Station |
#|                                                            |
#| This code originally developed by:                         |
#| Ryan Harper and Christopher Glendenning                    |
#| March, April 2000                                          |
#|                                                            |
#| Filename: wiz_selectpack.tcl                               |
#| Last Modified: April 11, 2000 by Ryan Harper               |
#| Changes: centered all windows with call 04.11.00 RAH       |
#|          removed Script dir hardcode 04.11.00 RAH          |
#/          removed /IBM/embedded hardcode 4.7.00 CMG         |
#| Description: allows customization of what goes on the      |
#|     custom flash using packages user previously built      |
#`------------------------------------------------------------'

proc select_packages {show_next_back} {
    check_for_win {.win}
    global lh
    puts $lh [format "%s" "Starting select_packages"]
    puts $lh [format "%s=%s" "Running_in_Wizmode" "$show_next_back"]
    flush $lh

    global CFBUILD_DIR
    global CFBUILD_DIR_NO_SLASH
    global SCRIPT_DIR
    global BOOTDIR
    global NETSCAPE_ROOT
    global IBM_JVM_ROOT
    global GTK_SOURCE
    global REAL7_ROOT
    global INSTALL_DEST
    global INSTALL_SOURCE
    global FVWM2_SOURCE
    global FVWM2_ICON_SOURCE
    global GIMP_SOURCE
    global GIMP_LIB_SOURCE


    if {[winfo exists .win]} {
	wm deiconify .win
	return
    }

    set win [toplevel .win -width 500 -height 300]
    wm title .win {IBM Linux Setup - Compact Flash Image Builder}
    wm geometry .win 500x300+312+134
    wm resizable .win 0 0
    centerwin {.win}

    frame .win.left -width 200 -height 300
    frame .win.left.sep -width 2 -height 300 -borderwidth 2 -relief sunken
    frame .win.right -width 300 -height 300
    frame .win.right.sep -width 300 -height 2 -borderwidth 2 -relief sunken

    checkbutton .win.left.ica -variable select_ica -onvalue 1 -offvalue 0\
      -text "ICA Client" -state disabled
    checkbutton .win.left.ibmjvm -variable select_jvm -onvalue 1 -offvalue 0\
      -text "IBM JVM" -state disabled
    checkbutton .win.left.gimp -variable select_gimp -onvalue 1 -offvalue 0\
      -text "Gimp" -state disabled
    checkbutton .win.left.netscape -variable select_netscape -onvalue 1\
      -offvalue 0 -text "Netscape 4.72" -state disabled
    checkbutton .win.left.real7 -variable select_real7 -onvalue 1 -offvalue 0\
      -text "RealPlayer 7" -state disabled
    checkbutton .win.left.fvwm2 -variable select_fvwm2 -onvalue 1 -offvalue 0\
      -text "Fvwm2"
    checkbutton .win.left.fvwm95 -variable select_fvwm95 -onvalue 1\
      -offvalue 0 -text "Fvwm95"

    if {$show_next_back} {
	button .win.left.next -text {Next >} -command {ChangePage\
	  "choose_settings" "1"}
	button .win.left.back -text {< Back} -command {ChangePage\
	  "create_partition" "1"}
	place .win.left.back -x 8 -y 260
	place .win.left.next -x 85 -y 260
    }

    button .win.right.button_build -width 10 -text "Build"\
      -command cf_build_check

    label .win.left.label_heading -text "Select Packages"
    label .win.right.label_message -justify "left" -text "Please select the\
      packages to be installed from\n the list on the left. You must choose\
      one of the\n X Windows Managers (Fvwm2, Fvwm95). When you have\n\
      selected the packages to be installed, click on\n Build to begin\
      installation.\n"

    place .win.left -x 0 -y 0
    place .win.left.sep -x 160 -y 0
    place .win.left.label_heading -x 10 -y 20

    place .win.left.ica -x 15 -y 40
    place .win.left.ibmjvm -x 15 -y 70
    place .win.left.gimp -x 15 -y 100
    place .win.left.netscape -x 15 -y 130
    place .win.left.real7 -x 15 -y 160
    place .win.left.fvwm2 -x 15 -y 190
    place .win.left.fvwm95 -x 15 -y 220

    place .win.right -x 180 -y 0
    place .win.right.sep -x 0 -y 245
    place .win.right.label_message -x 10 -y 20
    place .win.right.button_build -x 100 -y 260

    proc cf_build_check {} {
	global select_jvm
	global select_gimp
	global select_netscape
	global select_real7
	global select_fvwm2
	global select_fvwm95
	global select_ica

	set wm1 [expr $select_fvwm2 == 0]
	set wm2 [expr $select_fvwm95 == 0]
	set result [expr $wm1 && $wm2]
	if {$result == 1} {
	    tk_messageBox -message "You must select an X Windows Manager."
	} {
	    cf_build
	}
    }

    proc cf_build {} {
	global lh
	puts $lh [format "%s" "Starting cf_build"]
	flush $lh

	global CFBUILD_DIR
	global CFBUILD_DIR_NO_SLASH
	global SCRIPT_DIR
	global select_jvm
	global select_gimp
	global select_netscape
	global select_real7
	global select_fvwm2
	global select_fvwm95
	global select_ica
	global FVWM2_SOURCE
	global FVWM2_ICON_SOURCE
	set OS_installed false



	proc installBase {} {
	    global OS_installed
	    global CFBUILD_DIR_NO_SLASH
	    global CFBUILD_DIR
	    global SCRIPT_DIR
	    global lh
	    puts $lh [format "%s" "Starting installBase"]
	    flush $lh
	    cd $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR
	    exec ./mountdevice.sh &
	    cd $CFBUILD_DIR
	    update
	    toplevel .top -width 250 -height 150
	    wm resizable .top 0 0
	    wm title .top " "
	    label .top.message -text "Building Base OS Install..."
	    pack .top.message -padx 50 -pady 50
	    wm geometry .top +360+340
	    update idletasks
	    buildBaseTar
	    .top.message configure -text "Build Complete"
	    after 1000
	    destroy .top
	    if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/base.tar.gz] == 1} {
		update
		toplevel .top -width 250 -height 150
		wm resizable .top 0 0
		wm title .top " "
		label .top.message -text "Installing Base OS...\nPlease Wait"
		pack .top.message -padx 50 -pady 50
		wm geometry .top +360+340
		update idletasks
		cd /mnt/hd1
		exec tar -xzf $CFBUILD_DIR_NO_SLASH/Packages/base.tar.gz
		cd /mnt/hd2
		exec tar\
		  -xzf $CFBUILD_DIR_NO_SLASH/Custom/eLinux_partition2.tar.gz
		cd $CFBUILD_DIR
		.top.message configure -text "Installation Complete"
		after 1000
		set OS_installed true
		destroy .top
	    } {
		tk_messageBox -message "Base OS not installed."
	    }
	    return $OS_installed
	}

	set OS_installed [installBase]

	if {$OS_installed} {
	    cd /mnt/hd1
	    if {$select_ica == 1} {
		update
		toplevel .top -width 250 -height 150
		wm title .top "Install"
		wm resizable .top 0 0
		label .top.message -text "Installing ICA Client...\nPlease Wait"
		pack .top.message -padx 50 -pady 50
		centerwin .top
		update
		exec tar -xzf $CFBUILD_DIR_NO_SLASH/Packages/ica.tar.gz
		exec $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/ica_library.sh
		.top.message configure -text "Installation Complete"
		after 1000
		destroy .top
	    }
	    if {$select_jvm == 1} {
		unpack_tar "Installing IBM JVM...\nPlease Wait"\
		  "linux-ibm-jvm.tar.gz" "Installation Complete"
	    }
	    if {$select_gimp == 1} {
		unpack_tar "Installing Gimp...\nPlease Wait" "gimp.tar.gz"\
		  "Installation Complete"
	    }
	    if {$select_netscape == 1} {
		unpack_tar "Installing Netscape...\nPlease Wait"\
		  "netscape.tar.gz" "Installation Complete"
	    }
	    if {$select_real7 == 1} {
		unpack_tar "Installing RealPlayer7...\nPlease Wait"\
		  "real7.tar.gz" "Installation Complete"
	    }
	    if {$select_fvwm95 == 1} {
		tk_messageBox -message "At this time FVWM95 is not available."
	    }
	    if {$select_fvwm2 == 1} {
		if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/fvwm2.tar.gz]\
		  == 0} {
		    set fvwm2_prompt "Where are the FVWM2 RPMS(2)?\n(Main and\
		      Icon)"
		    set type "fvwm2"
		    set fvwm2_cmd "finish fvwm2_install"
		    get_dir $fvwm2_prompt $type "2" $fvwm2_cmd
		} {
		    unpack_tar "Installing FVWM2...\nPlease Wait"\
		      "fvwm2.tar.gz" "Installation Complete"
		}
	    }
	}

	cd $CFBUILD_DIR
	return
    }

    proc check_for_tars {} {
	global lh
	puts $lh [format "%s" "Starting chcek_for_tars"]
	flush $lh

	global CFBUILD_DIR_NO_SLASH

	if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/linux-ibm-jvm.tar.gz]\
	  == 1} {
	    .win.left.ibmjvm configure -state normal
	}
	if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/gimp.tar.gz] == 1} {
	    .win.left.gimp configure -state normal
	}

	if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/netscape.tar.gz] == 1} {
	    .win.left.netscape configure -state normal
	}

	if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/real7.tar.gz] == 1} {
	    .win.left.real7 configure -state normal
	}

	if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/ica.tar.gz] == 1} {
	    .win.left.ica configure -state normal
	}

	return
    }

    check_for_tars

}

########################################################################
#========================Base OS Build ================================#
########################################################################

proc buildBaseTar {} {
    global lh
    puts $lh [format "%s" "Starting buildBaseTar"]
    flush $lh

    global CFBUILD_DIR
    global CFBUILD_DIR_NO_SLASH
    global SCRIPT_DIR

    global BOOTDIR

    exec mkdir -p $CFBUILD_DIR_NO_SLASH/basetemp
    set HOME "$CFBUILD_DIR_NO_SLASH/basetemp"
    exec cp -a $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/BaseTarFileList.txt $HOME
    exec cp -a $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/make_base_dirs.sh $HOME

    cd $HOME

    set filelistloc "./BaseTarFileList.txt"
    set ferrorloc "./errors.txt"

    exec ./make_base_dirs.sh 2> make_base.log

    if {[file exists $filelistloc]} {

	set fd [open $filelistloc r]
	set ferror [open $ferrorloc w]
	#init badcopy to be false
	set badcopy false

	#grab a string, check if we are at eof, then loop, grab another string


	if {[file exists $HOME/Validate] == 0} {
	    set counter 0
	    while {[gets $fd instring] > 0} {
		#make a list out of the string with source and path
		set pathlist [split $instring]

		#assign our strings for source and destination from the list
		set sourcefile [lindex $pathlist 0]
		set destpath [lindex $pathlist 1]

		#	tk_messageBox -message "$sourcefile $destpath"

		#does the source exist and is the destination a directory?
		if {[file exists $sourcefile]} {
		    if {[file isdirectory $destpath]} {
			#copy our files
			file copy -force $sourcefile $destpath
		    } {
			file mkdir $destpath
			file copy -force $sourcefile $destpath
		    }
		    #if we get to this else the source file doesn't exist
		} {
		    set badcopy true
		    puts $ferror $sourcefile
		}
	    } ;#end of the while loop

	} ;#end of if, skip copy if valid copy exists


	close $fd
	close $ferror

	if {$badcopy} {
	    tk_messageBox -title "Copy Errors" -message "There were errors\
	      during the copy process.\nPlease  look at errors.txt for a list\
	      of files that were unable to be copied."
	} {
	    file delete $ferror
	    #we know our copy went through successfully so lets make our tar!
	    cd $HOME
	    exec touch Validate
	    if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/base.tar.gz] == 0} {
		cd $CFBUILD_DIR
		.top.message configure -text "Building Package"
		update
		exec $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/base_tarbuilder.sh
		.top.message configure -text "Build Complete"
		update
		return
	    }
	    return
	}

    } {
	tk_messageBox -title Error -message "BaseTarFileList.txt was not\
	  found. Aborting execution."
    }

}


proc fvwm2_install {} {
    global lh
    puts $lh [format "%s" "Starting fvwm2_install"]
    flush $lh

    action_window "Building and Installing FVMW2 package...\nPlease Wait."\
      "./fvwm2_install.sh" "fvmw2.log" "Build Complete"
}

==> nstation_rh61_cfbuilder_2.4.02.tar: IBM/CFBuilder_2.4.02/Source/wiz_selectpack.tcl <==
#.------------------------------------------------------------,
#| Compact Flash Builder - IBM Embedded Linux Network Station |
#|                                                            |
#| This code originally developed by:                         |
#| Ryan Harper and Christopher Glendenning                    |
#| March, April 2000                                          |
#|                                                            |
#| Filename: wiz_selectpack.tcl                               |
#| Last Modified: April 26, 2000 by Ryan Harper               |
#| Changes: fixed custom_install/fvwm2 overlap 04.26.00 RAH   |
#|          added custom_install proc 04.21.00 RAH            |
#|          centered all windows with call 04.11.00 RAH       |
#|          removed Script dir hardcode 04.11.00 RAH          |
#|          removed /IBM/embedded hardcode 4.7.00 CMG         |
#| Description: allows customization of what goes on the      |
#|     custom flash using packages user previously built      |
#`------------------------------------------------------------'

proc select_packages {show_next_back} {
    check_for_win {.win}
    global lh
    puts $lh [format "%s" "Starting select_packages"]
    puts $lh [format "%s=%s" "Running_in_Wizmode" "$show_next_back"]
    flush $lh

    global CFBUILD_DIR
    global CFBUILD_DIR_NO_SLASH
    global SCRIPT_DIR
    global BOOTDIR
    global NETSCAPE_ROOT
    global IBM_JVM_ROOT
    global GTK_SOURCE
    global REAL7_ROOT
    global INSTALL_DEST
    global INSTALL_SOURCE
    global FVWM2_SOURCE
    global FVWM2_ICON_SOURCE
    global GIMP_SOURCE
    global GIMP_LIB_SOURCE


    if {[winfo exists .win]} {
	wm deiconify .win
	return
    }

    set win [toplevel .win -width 500 -height 300]
    wm title .win {IBM Linux Setup - Compact Flash Image Builder}
    wm geometry .win 500x300+312+134
    wm resizable .win 0 0
    centerwin {.win}

    frame .win.left -width 200 -height 300
    frame .win.left.sep -width 2 -height 300 -borderwidth 2 -relief sunken
    frame .win.right -width 300 -height 300
    frame .win.right.sep -width 300 -height 2 -borderwidth 2 -relief sunken

    checkbutton .win.left.ica -variable select_ica -onvalue 1 -offvalue 0\
      -text "ICA Client" -state disabled
    checkbutton .win.left.ibmjvm -variable select_jvm -onvalue 1 -offvalue 0\
      -text "IBM JVM" -state disabled
    checkbutton .win.left.gimp -variable select_gimp -onvalue 1 -offvalue 0\
      -text "Gimp" -state disabled
    checkbutton .win.left.netscape -variable select_netscape -onvalue 1\
      -offvalue 0 -text "Netscape 4.72" -state disabled
    checkbutton .win.left.real7 -variable select_real7 -onvalue 1 -offvalue 0\
      -text "RealPlayer 7" -state disabled
    checkbutton .win.left.custom -variable select_custom -onvalue 1 -offvalue 0\
      -text "Custom App"
    checkbutton .win.left.fvwm2 -variable select_fvwm2 -onvalue 1 -offvalue 0\
      -text "Fvwm2"
    checkbutton .win.left.fvwm95 -variable select_fvwm95 -onvalue 1\
      -offvalue 0 -text "Fvwm95"

    if {$show_next_back} {
	button .win.left.next -text {Next >} -command {ChangePage\
	  "choose_settings" "1"}
	button .win.left.back -text {< Back} -command {ChangePage\
	  "create_partition" "1"}
	place .win.left.back -x 8 -y 260
	place .win.left.next -x 85 -y 260
    }

    button .win.right.button_build -width 10 -text "Build"\
      -command cf_build_check

    label .win.left.label_heading -text "Select Packages"
    label .win.right.label_message -justify "left" -text "Please select the\
      packages to be installed from\n the list on the left. You must choose\
      one of the\n X Windows Managers (Fvwm2, Fvwm95). When you have\n\
      selected the packages to be installed, click on\n Build to begin\
      installation.\n"

    place .win.left -x 0 -y 0
    place .win.left.sep -x 160 -y 0
#    place .win.left.label_heading -x 10 -y 20

    place .win.left.ica -x 15 -y 20
    place .win.left.ibmjvm -x 15 -y 50
    place .win.left.gimp -x 15 -y 80
    place .win.left.netscape -x 15 -y 110
    place .win.left.real7 -x 15 -y 140
    place .win.left.custom -x 15 -y 170
    place .win.left.fvwm2 -x 15 -y 200
    place .win.left.fvwm95 -x 15 -y 230

    place .win.right -x 180 -y 0
    place .win.right.sep -x 0 -y 245
    place .win.right.label_message -x 10 -y 20
    place .win.right.button_build -x 100 -y 260

    proc cf_build_check {} {
	global select_jvm
	global select_gimp
	global select_netscape
	global select_real7
	global select_fvwm2
	global select_fvwm95
	global select_ica

	set wm1 [expr $select_fvwm2 == 0]
	set wm2 [expr $select_fvwm95 == 0]
	set result [expr $wm1 && $wm2]
	if {$result == 1} {
	    tk_messageBox -message "You must select an X Windows Manager."
	} {
	    cf_build
	}
    }

    proc cf_build {} {
	global lh
	puts $lh [format "%s" "Starting cf_build"]
	flush $lh

	global CFBUILD_DIR
	global CFBUILD_DIR_NO_SLASH
	global SCRIPT_DIR
	global select_jvm
	global select_gimp
	global select_netscape
	global select_real7
	global select_fvwm2
	global select_fvwm95
	global select_ica
	global select_custom
	global FVWM2_SOURCE
	global FVWM2_ICON_SOURCE
	set OS_installed false



	proc installBase {} {
	    global OS_installed
	    global CFBUILD_DIR_NO_SLASH
	    global CFBUILD_DIR
	    global SCRIPT_DIR
	    global lh
	    puts $lh [format "%s" "Starting installBase"]
	    flush $lh
	    cd $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR
	    exec ./mountdevice.sh &
	    cd $CFBUILD_DIR
	    update
	    toplevel .top -width 250 -height 150
	    wm resizable .top 0 0
	    wm title .top " "
	    label .top.message -text "Building Base OS Install..."
	    pack .top.message -padx 50 -pady 50
	    wm geometry .top +360+340
	    update idletasks
	    buildBaseTar
	    .top.message configure -text "Build Complete"
	    after 1000
	    destroy .top
	    if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/base.tar.gz] == 1} {
		update
		toplevel .top -width 250 -height 150
		wm resizable .top 0 0
		wm title .top " "
		label .top.message -text "Installing Base OS...\nPlease Wait"
		pack .top.message -padx 50 -pady 50
		wm geometry .top +360+340
		update idletasks
		cd /mnt/hd1
		exec tar -xzf $CFBUILD_DIR_NO_SLASH/Packages/base.tar.gz
		cd /mnt/hd2
		exec tar\
		  -xzf $CFBUILD_DIR_NO_SLASH/Custom/eLinux_partition2.tar.gz
		cd $CFBUILD_DIR
		.top.message configure -text "Installation Complete"
		after 1000
		set OS_installed true
		destroy .top
	    } {
		tk_messageBox -message "Base OS not installed."
	    }
	    return $OS_installed
	}

	set OS_installed [installBase]

	if {$OS_installed} {
	    cd /mnt/hd1
	    if {$select_ica == 1} {
		update
		toplevel .top -width 250 -height 150
		wm title .top "Install"
		wm resizable .top 0 0
		label .top.message -text "Installing ICA Client...\nPlease Wait"
		pack .top.message -padx 50 -pady 50
		centerwin .top
		update
		exec tar -xzf $CFBUILD_DIR_NO_SLASH/Packages/ica.tar.gz
		exec $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/ica_library.sh
		.top.message configure -text "Installation Complete"
		after 1000
		destroy .top
	    }
	    if {$select_jvm == 1} {
		unpack_tar "Installing IBM JVM...\nPlease Wait"\
		  "linux-ibm-jvm.tar.gz" "Installation Complete"
	    }
	    if {$select_gimp == 1} {
		unpack_tar "Installing Gimp...\nPlease Wait" "gimp.tar.gz"\
		  "Installation Complete"
	    }
	    if {$select_netscape == 1} {
		unpack_tar "Installing Netscape...\nPlease Wait"\
		  "netscape.tar.gz" "Installation Complete"
	    }
	    if {$select_real7 == 1} {
		unpack_tar "Installing RealPlayer7...\nPlease Wait"\
		  "real7.tar.gz" "Installation Complete"
	    }
	    if {$select_fvwm2 == 1} {
		if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/fvwm2.tar.gz]\
		  == 0} {
		    set fvwm2_prompt "Where are the FVWM2 RPMS(2)?\n(Main and\
		      Icon)"
		    set type "fvwm2"
		    set fvwm2_cmd "finish fvwm2_install"
	 	    global proceed
		    set proceed 0
		    set proceed [get_dir $fvwm2_prompt $type "2" $fvwm2_cmd]
		    vwait proceed
		} 
		unpack_tar "Installing FVWM2...\nPlease Wait"\
		"fvwm2.tar.gz" "Installation Complete"
	    }
            if {$select_custom == 1} {
             	custom_install
	    }
	    if {$select_fvwm95 == 1} {
		tk_messageBox -message "At this time FVWM95 is not available."
	    }
	}

	cd $CFBUILD_DIR
	return
    }

    proc check_for_tars {} {
	global lh
	puts $lh [format "%s" "Starting chcek_for_tars"]
	flush $lh

	global CFBUILD_DIR_NO_SLASH

	if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/linux-ibm-jvm.tar.gz]\
	  == 1} {
	    .win.left.ibmjvm configure -state normal
	}
	if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/gimp.tar.gz] == 1} {
	    .win.left.gimp configure -state normal
	}

	if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/netscape.tar.gz] == 1} {
	    .win.left.netscape configure -state normal
	}

	if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/real7.tar.gz] == 1} {
	    .win.left.real7 configure -state normal
	}

	if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/ica.tar.gz] == 1} {
	    .win.left.ica configure -state normal
	}

	return
    }

    check_for_tars

}

########################################################################
#========================Base OS Build ================================#
########################################################################

proc buildBaseTar {} {
    global lh
    puts $lh [format "%s" "Starting buildBaseTar"]
    flush $lh

    global CFBUILD_DIR
    global CFBUILD_DIR_NO_SLASH
    global SCRIPT_DIR

    global BOOTDIR

    exec mkdir -p $CFBUILD_DIR_NO_SLASH/basetemp
    set HOME "$CFBUILD_DIR_NO_SLASH/basetemp"
    exec cp -a $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/BaseTarFileList.txt $HOME
    exec cp -a $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/make_base_dirs.sh $HOME

    cd $HOME

    set filelistloc "./BaseTarFileList.txt"
    set ferrorloc "./errors.txt"

    exec ./make_base_dirs.sh 2> make_base.log

    if {[file exists $filelistloc]} {

	set fd [open $filelistloc r]
	set ferror [open $ferrorloc w]
	#init badcopy to be false
	set badcopy false

	#grab a string, check if we are at eof, then loop, grab another string


	if {[file exists $HOME/Validate] == 0} {
	    set counter 0
	    while {[gets $fd instring] > 0} {
		#make a list out of the string with source and path
		set pathlist [split $instring]

		#assign our strings for source and destination from the list
		set sourcefile [lindex $pathlist 0]
		set destpath [lindex $pathlist 1]

		#	tk_messageBox -message "$sourcefile $destpath"

		#does the source exist and is the destination a directory?
		if {[file exists $sourcefile]} {
		    if {[file isdirectory $destpath]} {
			#copy our files
			file copy -force $sourcefile $destpath
		    } {
			file mkdir $destpath
			file copy -force $sourcefile $destpath
		    }
		    #if we get to this else the source file doesn't exist
		} {
		    set badcopy true
		    puts $ferror $sourcefile
		}
	    } ;#end of the while loop

	} ;#end of if, skip copy if valid copy exists


	close $fd
	close $ferror

	if {$badcopy} {
	    tk_messageBox -title "Copy Errors" -message "There were errors\
	      during the copy process.\nPlease  look at errors.txt for a list\
	      of files that were unable to be copied."
	} {
	    file delete $ferror
	    #we know our copy went through successfully so lets make our tar!
	    cd $HOME
	    exec touch Validate
	    if {[file exists $CFBUILD_DIR_NO_SLASH/Packages/base.tar.gz] == 0} {
		cd $CFBUILD_DIR
		.top.message configure -text "Building Package"
		update
		exec $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/base_tarbuilder.sh
		.top.message configure -text "Build Complete"
		update
		return
	    }
	    return
	}

    } {
	tk_messageBox -title Error -message "BaseTarFileList.txt was not\
	  found. Aborting execution."
    }

}


proc fvwm2_install {} {
    global lh
    puts $lh [format "%s" "Starting fvwm2_install"]
    flush $lh

    action_window "Building and Installing FVWM2 package...\nPlease Wait."\
      "./fvwm2_install.sh" "fvwm2.log" "Build Complete"
    return 1
}

proc custom_install {} {
    global a_path
    global lh
    global CFBUILD_DIR_NO_SLASH
    global SCRIPT_DIR
    global val
    puts $lh [format "%s" "Starting custom_install"]
    get_dir "Where is the Custom App Tar Package?" "custom" "1" "custom_unpack"
    return
}

proc custom_unpack {var1 var2} {
    destroy .win.top
    global a_path
    global lh
    global logfilename
    global CFBUILD_DIR_NO_SLASH
    global SCRIPT_DIR
    puts $lh [format "\t%s->%s" "Unpacking custom app" "$a_path(0)"]
    flush $lh

    set appname "$a_path(0)"
    update
    toplevel .action -width 250 -height 150
    wm resizable .action 0 0
    wm title .action " "
    label .action.message -text "Installing Custom Application\n$appname\nPlease Wait"
    pack .action.message -padx 50 -pady 50
    centerwin .action
    update
    cd /mnt/hd1
    exec tar -xzf $appname >>&$CFBUILD_DIR_NO_SLASH/Log/$logfilename
    set lh [open $CFBUILD_DIR_NO_SLASH/Log/$logfilename a]
    .action.message configure -text "Installation Complete"
    after 1000
    destroy .action
    if {[confirm_ask "Do you want to install another Custom Application?"]} {
	custom_install
    }
    return 1
}
